@@ -565,7 +565,7 @@ fmtDOI <- switch(docstyle, html = function(doi){
                         }
                       }, markdown = function(doi){
                           if (length(doi)){
-                            paste0("DOI: [href=http://dx.doi.org/", doi, "](", doi, ").")
+                            paste0("DOI: [", doi, "](http://dx.doi.org/", doi, ").")
                           }
                         }, label(prefix = 'DOI: ', suffix = '.'))
   
@@ -1303,4 +1303,4 @@ toRd.BibEntry <- function(obj, ...) {
   	    paste("bibtype", attr(paper, "bibtype"), "not implemented") ))
   }
   result
-}
\ No newline at end of file
+}
